
# Surk Dili
Türkçe, ürün oluşturma odaklı, web&mobil&masaüstü desteği planlanan programlama dilidir.

> Shell + Turk -> Surk

# Amaç
Yazılıma başlayan kişilerin yazılım öğrenmeden önce İngilizce öğrenme zorunluluklarını ortadan kaldırarak üzerimizdeki dil kaynaklı handikapları en aza indirmek amacıyla, kurumsal yazılım için kullanılabilecek, modern, güçlü, ürün odaklı bir yazılım dili oluşturmaktır.

Anadili Türkçe olan kişilerin kodlamaya Türkçe ile başlamasıyla birlikte algoritma, veri yapıları, komut setleri, derleyiciler gibi yazılımsal kavramları da kendi anadillerinde öğrenmeleridir.

Kurumsal dünyada aktif olarak kullanılan bir dil ortaya çıkartmak bu projenin amaçları arasındadır.


# Başlarken
1. Aklınızdaki soruları, yaşadığınız teknik sorunlar da dahil olmak üzere [http://sayisalfelsefe.com](http://sayisalfelsefe.com/) adresinde sorabilir ve tartışabilirsiniz.
2. Teknik öneriler ve sorular için issue açabilirsiniz.
3. Bu proje, hiçbir ticari amaç güdülmeden tamamen ücretsiz ve gönüllü olarak, hiçbir sponsorluk ve bağış almadan başlatılmıştır. Kullanılması tamamiyle ücretsizdir.
4. Projenin iyi niyetle ve tamamen karşılıksız olarak başlatıldığını hatırlatır, eleştiri ve öneri dilinize dikkat etmenizi önemle rica ederim. 


# Yükleme
Şurk dili bir Python paketi olarak dağıtılır ve dilin yüklemek için cihazınızda Python yüklü olmalıdır.
Öncelikle şuradaki rehberi takip ederek sisteminize Python3 ü yükleyiniz. İşleminiz tamamlandığında pip 'i de yüklemiş olacaksınız. 
Burada dikkat etmeniz gereken şey $ işaretini terminale kopyalamamanız gerektiği. Yani;
Komşu şöyle ise; 

    $ sudo apt install python3.6
   Başındaki işareti($) silerek şu şekilde yapıştırınız;
   

    sudo apt install python3.6

[Türkçe Python kurulum rehberi](https://tutorial.djangogirls.org/tr/python_installation/)

Bu işlem bittikten sonra şu komut ile surk derleyicisiniz yükleniyiniz;

    pip3 install surk

Sonuç olarak şu komutu uçbirimde(terminal, CMD) yürüttüğünüzde "başarılıyla kuruldu." çıktısını almanız gerekmekte.


# Kodlama Rehberi
> Yakında.

# Yol Haritası

 - [ ] Çekirdek kütüphanenin oluşturulması
	 - [x] Terminal girdi-çıktı kabiliyetlerinin eklenmesi
	 - [x] Tip dönüşümlerinin eklenmesi
	 - [ ] Metin işlemleri kabiliyetlerinin eklenmesi
	 - [ ] Dizi, liste vb. veri yapılarının eklenmesi
	 - [ ] Dosya işlemlerinin eklenmesi
 - [ ] Referans sayfasının oluşturulması 
 - [ ] Örnek proje videolarının oluşturulması 
 - [ ] Arayüz kütüphanesinin eklenmesi 
 - [ ] VSCode için eklenti oluşturulması 
 - [ ] Web kütüphanelerinin eklenmesi



# Geri bildirim, Soru, Sorun ve Diğerleri
Eğer takıldığınız bir nokta varsa, bir noktada teknik bir sorun yaşıyorsanız topluluk forumuna sorabilirsiniz; [http://sayisalfelsefe.com/](http://sayisalfelsefe.com/)

Dilin mimarisi, interpreter yapısı gibi daha derin konularda ise issue açabilirsiniz.


### Sevgi ve saygılarımla.

